@@ -57,16 +57,64 @@ namespace dynsbm{
     }
     correctMultinomproba();
   }
+  
+  void DynSBMDiscrete::updateFrozenTheta(int*** const Y){// M-step
+    for(int t=0;t<_t;t++)
+      for(int q=0;q<_q;q++)
+        for(int l=0;l<_q;l++)
+          for(int k=0;k<_k;k++) _multinomprobaql[t][q][l][k] = 0.;
+    
+    DynSBMDiscreteAddEventFunctor addEventFunctor(*this);
+    updateFrozenThetaCore<DynSBMDiscreteAddEventFunctor>(Y, addEventFunctor);
+    
+    // symmetrize+normalize
+    for(int q=(_isdirected?0:1);q<_q;q++){
+      for(int l=0;l<q;l++){
+	double summultinomprobaql = 0.;
+	for(int k=0;k<_k;k++) summultinomprobaql += _multinomprobaql[0][q][l][k];
+	if (summultinomprobaql>0)
+	  for(int k=0;k<_k;k++){
+	    _multinomprobaql[0][q][l][k] = _multinomprobaql[0][q][l][k]/summultinomprobaql;
+	    if(!_isdirected) _multinomprobaql[0][l][q][k] = _multinomprobaql[0][q][l][k];
+	  }
+      }        	
+      if(_isdirected)
+	for(int l=q+1;l<_q;l++){
+	  double summultinomprobaql = 0.;
+	  for(int k=0;k<_k;k++) summultinomprobaql += _multinomprobaql[0][q][l][k];
+	  if (summultinomprobaql>0)
+	    for(int k=0;k<_k;k++){
+	      _multinomprobaql[0][q][l][k] = _multinomprobaql[0][q][l][k]/summultinomprobaql;
+	    }
+	}      
+    }
+    for(int q=0;q<_q;q++){// symmetrize+normalize
+      double summultinomprobaqq = 0.;
+      for(int k=0;k<_k;k++) summultinomprobaqq += _multinomprobaql[0][q][q][k];
+      if(summultinomprobaqq>0)
+	for(int k=0;k<_k;k++) _multinomprobaql[0][q][q][k] = _multinomprobaql[0][q][q][k]/summultinomprobaqq;
+    }
+    // note the constraint multinomprobaql[t,q,l,.] = multinomprobaql[0,q,l,.]
+    for(int t=1;t<_t;t++){
+      for(int q=0;q<_q;q++)
+	for(int l=0;l<_q;l++)
+	  for(int k=0;k<_k;k++) _multinomprobaql[t][q][l][k] =  _multinomprobaql[0][q][l][k];
+    }
+    correctMultinomproba();
+  }
+  
   void DynSBMDiscrete::correctMultinomproba(){ // numerical issue : avoid too small value for multinomproba
     for(int t=0;t<_t;t++){
-        for(int q=1;q<_q;q++){
+        for(int q=0;q<_q;q++){
             for(int l=0;l<_q;l++){
                 for(int k=0;k<_k;k++){
-                  if(_multinomprobaql[t][q][l][k]<1e-7)
-                    _multinomprobaql[t][q][l][k] = 1e-7;
-                  if(_multinomprobaql[t][q][l][k]>(1-1e-7)){
-                        _multinomprobaql[t][q][l][k] = 1-1e-7;
+                  if(_multinomprobaql[t][q][l][k]<precision)
+                    _multinomprobaql[t][q][l][k] = precision;
+                  if(_multinomprobaql[t][q][l][k]>(1-precision)){
+                        _multinomprobaql[t][q][l][k] = 1-precision;
                   }
+		  // trick: store log(_multinomprobaql[t][q][l][k])
+		   _multinomprobaql[t][q][l][k] = log(_multinomprobaql[t][q][l][k]);
                 }
             }
         }
